@@ -2,9 +2,9 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2016 by the BibleTime developers.
+* Copyright 1999-2020 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -12,6 +12,7 @@
 
 #include "btbookshelftreemodel.h"
 
+#include <QtGlobal>
 #include <type_traits>
 #include "../../util/btassert.h"
 #include "../../util/btconnect.h"
@@ -75,7 +76,7 @@ int BtBookshelfTreeModel::rowCount(const QModelIndex & parent) const {
 }
 
 int BtBookshelfTreeModel::columnCount(const QModelIndex & parent) const {
-    Q_UNUSED(parent);
+    Q_UNUSED(parent)
 
     return 1;
 }
@@ -123,6 +124,7 @@ QVariant BtBookshelfTreeModel::data(const QModelIndex & index, int role) const {
         case Qt::CheckStateRole:
             if (!m_checkable)
                 break;
+            Q_FALLTHROUGH();
 
         case BtBookshelfTreeModel::CheckStateRole:
             return i->checkState();
@@ -131,9 +133,9 @@ QVariant BtBookshelfTreeModel::data(const QModelIndex & index, int role) const {
             /* This case is just an optimization. */
             if (i->type() == Item::ITEM_MODULE) {
                 const ModuleItem & mi = *static_cast<const ModuleItem *>(i);
-                return qVariantFromValue(static_cast<void *>(&mi.moduleInfo()));
+                return QVariant::fromValue(static_cast<void *>(&mi.moduleInfo()));
             }
-            return 0;
+            return QVariant::fromValue(nullptr);
 
         case Qt::DisplayRole:
         case Qt::DecorationRole:
