@@ -2,9 +2,9 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2016 by the BibleTime developers.
+* Copyright 1999-2020 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -144,7 +144,7 @@ public: /* Methods: */
 private: /* Methods: */
 
     inline void setParent(Item * parent) noexcept
-    { m_parent = (BT_ASSERT(parent), parent); }
+    { m_parent = (static_cast<void>(BT_ASSERT(parent)), parent); }
 
 private: /* Fields: */
 
@@ -162,7 +162,7 @@ public: /* Methods: */
     inline RootItem()
         : Item(Item::ITEM_ROOT) {}
 
-    inline bool fitFor(const CSwordModuleInfo &) const override { return true; }
+    bool fitFor(const CSwordModuleInfo &) const override;
 
 };
 
