@@ -2,10 +2,11 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
@@ -82,7 +83,7 @@ class BtInstallThread: public QThread {
         const QList<CSwordModuleInfo *> & m_modules;
         const QString m_destination;
         BtInstallMgr m_iMgr;
-        int m_currentModuleIndex;
+        int m_currentModuleIndex = 0;
         std::atomic<bool> m_stopRequested;
 
 };
