@@ -2,10 +2,11 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
@@ -60,7 +61,8 @@ class CSwordModuleSearch: public QObject {
           \param[in] modules the modules to search in.
         */
         inline void setModules(const BtConstModuleList &modules) {
-            BT_ASSERT(!modules.empty());
+            if (modules.empty())
+                return;
             BT_ASSERT(unindexedModules(modules).empty());
             m_searchModules = modules;
         }
