@@ -1,9 +1,12 @@
 /*********
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
+*
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
@@ -101,8 +104,8 @@ char ThmlToHtml::processText(sword::SWBuf &buf, const sword::SWKey *key,
         while (pos != -1) {
             bool isMorph = false;
             bool isStrongs = false;
-            value = QString::null;
-            valueClass = QString::null;
+            value = QString();
+            valueClass = QString();
 
             // check 3 attribute/value pairs
 
@@ -314,9 +317,11 @@ bool ThmlToHtml::handleToken(sword::SWBuf &buf, const char *token,
                     myUserData->inscriptRef = true;
                     myUserData->suspendTextPassThru = false;
 
-                    if (CSwordModuleInfo const * const mod =
-                            btConfig().getDefaultSwordModuleByType(
-                                    "standardBible"))
+                    CSwordModuleInfo * mod = btConfig().getDefaultSwordModuleByType("standardBible");
+                    if (! mod)
+                        mod = CSwordBackend::instance()->findFirstAvailableModule(CSwordModuleInfo::Bible);
+
+                    if (mod)
                     {
                         ;
                         BT_ASSERT(tag.getAttribute("passage"));
