@@ -1,9 +1,12 @@
 /*********
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
+*
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
@@ -128,7 +131,7 @@ QString CSwordVerseKey::book( const QString& newBook ) {
     }
 
     //return QString::fromUtf8( books[min][0].name ); //return the first book, i.e. Genesis
-    return QString::null;
+    return QString();
 }
 
 /** Sets the key we use to the parameter. */
