@@ -2,10 +2,11 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
@@ -98,7 +99,7 @@ class CSwordVerseKey : public CSwordKey, public sword::VerseKey {
         * Use "char Book()" to retrieve the book number of the current book.
         * @return The name of the current book
         */
-        QString book(const QString& newBook = QString::null);
+        QString book(const QString& newBook = QString());
 
         void setModule(const CSwordModuleInfo *newModule) override;
 
