@@ -1,9 +1,12 @@
 /*********
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
+*
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
@@ -33,7 +36,7 @@ CLanguageMgr *CLanguageMgr::instance() {
 }
 
 CLanguageMgr::CLanguageMgr()
-    : m_defaultLanguage("", "", QString::null)
+    : m_defaultLanguage("", "", QString())
     , m_langMap()
 {
     m_availableModulesCache.moduleCount = 0;
@@ -415,7 +418,7 @@ void CLanguageMgr::init() {
     //: Language name pt
     m_langList.append( new Language("pt", "Portuguese", QObject::tr("Portuguese")) );
     //: Language name pt_BR
-    m_langList.append( new Language("pt_BR", "Brasilian Portuguese", QObject::tr("Brasilian Portuguese")) );//added by ourself
+    m_langList.append( new Language("pt_BR", "Brazilian Portuguese", QObject::tr("Brazilian Portuguese")) );//added by ourself
     //  m_langList.append( new Language("qu", "Quechua", QObject::tr("Quechua")) );
     //: Language name qut
     m_langList.append( new Language("qut", "Quich\u00e9, West Central", QObject::tr("Quich\u00e9, West Central")) );
