@@ -1,9 +1,12 @@
 /*********
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
+*
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
@@ -62,6 +65,15 @@ BtModuleList CSwordBackend::moduleList(CSwordModuleInfo::ModuleType type) const
     return l;
 }
 
+CSwordModuleInfo * CSwordBackend::findFirstAvailableModule(CSwordModuleInfo::ModuleType type) {
+
+    Q_FOREACH(CSwordModuleInfo * m, moduleList())
+        if(m->type() == type)
+            return m;
+    return nullptr;
+
+}
+
 void CSwordBackend::uninstallModules(BtConstModuleSet const & toBeDeleted) {
     if (toBeDeleted.empty())
         return;
@@ -128,7 +140,7 @@ CSwordBackend::LoadError CSwordBackend::initModules(const SetupChangedReason rea
     m_dataModel.clear();
 
     sword::ModMap::iterator end = Modules.end();
-    const LoadError ret = static_cast<LoadError>(Load());
+    const LoadError ret = static_cast<LoadError>(load());
 
     for (sword::ModMap::iterator it = Modules.begin(); it != end; ++it) {
         sword::SWModule * const curMod = it->second;
@@ -157,22 +169,28 @@ CSwordBackend::LoadError CSwordBackend::initModules(const SetupChangedReason rea
         if (!newModule->hasVersion()
             || (newModule->minimumSwordVersion() <= sword::SWVersion::currentVersion))
         {
-            m_dataModel.addModule(newModule);
+
+            /* There is currently a deficiency in sword 1.8.1 in that backend->setCipherKey() does
+             * not work correctly for modules from which data was already fetched. Therefore we have to
+             * reload the modules. The cipher key must be set before any read occurs on the module.
+             * Reading from the module can happen in subtle ways. The addModule below causes a read
+             * to determine if the locked or unlocked icon is used by the model.
+             */
+            {
+                if (newModule->isEncrypted()) {
+                    const QString unlockKey = btConfig().getModuleEncryptionKey(newModule->name());
+                    if (!unlockKey.isNull())
+                        setCipherKey(newModule->name().toUtf8().constData(),
+                                     unlockKey.toUtf8().constData());
+                }
+            }
+
+                m_dataModel.addModule(newModule);
         } else {
             delete newModule;
         }
     }
 
-    // Unlock modules if keys are present:
-    Q_FOREACH(CSwordModuleInfo const * const mod, m_dataModel.moduleList()) {
-        if (mod->isEncrypted()) {
-            const QString unlockKey = btConfig().getModuleEncryptionKey(mod->name());
-            if (!unlockKey.isNull())
-                setCipherKey(mod->name().toUtf8().constData(),
-                             unlockKey.toUtf8().constData());
-        }
-    }
-
     emit sigSwordSetupChanged(reason);
     return ret;
 }
@@ -209,7 +227,7 @@ void CSwordBackend::AddRenderFilters(sword::SWModule * module,
 void CSwordBackend::shutdownModules() {
     m_dataModel.clear(true);
     //BT  mods are deleted now, delete Sword mods, too.
-    DeleteMods();
+    deleteAllModules();
 
     /* Cipher filters must be handled specially, because SWMgr creates them,
      * stores them in cipherFilters and cleanupFilters and attaches them to locked
@@ -274,7 +292,7 @@ CSwordModuleInfo * CSwordBackend::findModuleByDescription(const QString & descri
 
 CSwordModuleInfo * CSwordBackend::findModuleByName(const QString & name) const {
     Q_FOREACH(CSwordModuleInfo * const mod, m_dataModel.moduleList())
-        if (mod->name() == name)
+        if (mod->name().compare(name, Qt::CaseInsensitive) == 0)
             return mod;
     return nullptr;
 }
@@ -313,7 +331,7 @@ QString CSwordBackend::optionName(const CSwordModuleInfo::FilterTypes option) {
         case CSwordModuleInfo::morphSegmentation:
             return "Morph Segmentation";
     }
-    return QString::null;
+    return QString();
 }
 
 QString CSwordBackend::translatedOptionName(const CSwordModuleInfo::FilterTypes option) {
@@ -343,7 +361,7 @@ QString CSwordBackend::translatedOptionName(const CSwordModuleInfo::FilterTypes
         case CSwordModuleInfo::morphSegmentation:
             return QObject::tr("Morph segmentation");
     }
-    return QString::null;
+    return QString();
 }
 
 
@@ -374,7 +392,7 @@ QString CSwordBackend::configOptionName(const CSwordModuleInfo::FilterTypes opti
         case CSwordModuleInfo::morphSegmentation:
             return "MorphSegmentation";
     }
-    return QString::null;
+    return QString();
 }
 
 const QString CSwordBackend::booknameLanguage(const QString & language) {
@@ -413,7 +431,7 @@ void CSwordBackend::reloadModules(const SetupChangedReason reason) {
         // now re-read module configuration files
         loadConfigDir(configPath);
     } else if (config) {
-        config->Load();
+        config->load();
     }
 
     initModules(reason);
@@ -495,7 +513,10 @@ QStringList CSwordBackend::swordDirList() const {
     // Add the private sword path to the set if not there already:
     swordDirSet << getPrivateSwordConfigPath();
 
-    return QStringList::fromSet(swordDirSet);
+    QStringList swordDirs;
+    for (auto dir: swordDirSet)
+        swordDirs.append(dir);
+    return swordDirs;
 }
 
 void CSwordBackend::deleteOrphanedIndices() {
