@@ -2,16 +2,18 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
 #include "btinforendering.h"
 
 #include <QStringList>
+#include <QtGlobal>
 #include "../../util/btassert.h"
 #include "../btglobal.h"
 #include "../keys/cswordversekey.h"
@@ -25,13 +27,15 @@ using namespace Rendering;
 using namespace sword;
 
 namespace Rendering {
+namespace {
 
 class CrossRefRendering : public CHTMLExportRendering {
 public:
     CrossRefRendering(
             const DisplayOptions &displayOptions = btConfig().getDisplayOptions(),
             const FilterOptions &filterOptions = btConfig().getFilterOptions())
-     : CHTMLExportRendering(true, displayOptions, filterOptions) {;}
+        : CHTMLExportRendering(true, displayOptions, filterOptions)
+    {}
 
     QString entryLink(const KeyTreeItem &item, const CSwordModuleInfo *module) override {
         BT_ASSERT(module);
@@ -45,35 +49,30 @@ public:
         }
 
         switch (item.settings().keyRenderingFace) {
-            case KeyTreeItem::Settings::NoKey: {
-                linkText = QString::null;
+            case KeyTreeItem::Settings::NoKey:
+                linkText = QString();
                 break; //no key is valid for all modules
-            }
-            case KeyTreeItem::Settings::CompleteShort: {
+            case KeyTreeItem::Settings::CompleteShort:
                 if (isBible) {
                     linkText = QString::fromUtf8(vk.getShortText());
                     break;
                 }
-                //fall through for non-Bible modules
-            }
-            case KeyTreeItem::Settings::CompleteLong: {
+                Q_FALLTHROUGH();
+            case KeyTreeItem::Settings::CompleteLong:
                 if (isBible) {
                     linkText = vk.key();
                     break;
                 }
-                //fall through for non-Bible modules
-            }
-            case KeyTreeItem::Settings::SimpleKey: {
+                Q_FALLTHROUGH();
+            case KeyTreeItem::Settings::SimpleKey:
                 if (isBible) {
                     linkText = QString::number(vk.getVerse());
                     break;
                 }
-                //fall through for non-Bible modules
-            }
-            default: { //default behaviour to return the passed key
+                Q_FALLTHROUGH();
+            default: //default behaviour to return the passed key
                 linkText = item.key();
                 break;
-            }
         }
 
         if (!linkText.isEmpty()) { //if we have a valid link text
@@ -89,51 +88,41 @@ public:
                    .arg(linkText);
         }
 
-        return QString::null;
+        return QString();
     }
 
     QString finishText(const QString &text, const KeyTree &tree) override {
-        Q_UNUSED(tree);
+        Q_UNUSED(tree)
         return text;
     }
-};
+}; // class CrossRefRendering
 
+} // anonymous namespace
 
-ListInfoData detectInfo(QString const &data)
-{
+ListInfoData detectInfo(QString const & data) {
     ListInfoData list;
-    QStringList attrList = data.split("||");
+    auto const attrList(data.split("||"));
 
-    for (int i = 0; i < attrList.count(); i++) {
-        QString attrPair = attrList[i];
-        QStringList attr = attrPair.split("=");
-        if (attr.count() == 2) {
-            QString attrName = attr[0];
-            QString attrValue = attr[1];
+    for (auto const & attrPair : attrList) {
+        auto const attr(attrPair.split("="));
+        if (attr.size() == 2) {
+            auto const & attrName = attr[0];
+            auto const & attrValue = attr[1];
             if (attrName == "note") {
-                list.append( qMakePair(Footnote, attrValue));
-            }
-            if (attrName == "lemma") {
-                list.append( qMakePair(Lemma, attrValue));
-            }
-            if (attrName == "morph") {
-                list.append( qMakePair(Morph, attrValue));
-            }
-            if (attrName == "expansion") {
-                list.append( qMakePair(Abbreviation, attrValue));
-            }
-            if (attrName == "crossrefs") {
-                list.append( qMakePair(CrossReference, attrValue));
-            }
-            if (attrName == "href") {
-                list.append( qMakePair(Reference, attrValue));
-            }
-            if (attrName == "key") {
-                list.append( qMakePair(Key, attrValue));
+                list.append(qMakePair(Footnote, attrValue));
+            } else if (attrName == "lemma") {
+                list.append(qMakePair(Lemma, attrValue));
+            } else if (attrName == "morph") {
+                list.append(qMakePair(Morph, attrValue));
+            } else if (attrName == "expansion") {
+                list.append(qMakePair(Abbreviation, attrValue));
+            } else if (attrName == "crossrefs") {
+                list.append(qMakePair(CrossReference, attrValue));
+            } else if (attrName == "href") {
+                list.append(qMakePair(Reference, attrValue));
             }
         }
     }
-
     return list;
 }
 
@@ -162,12 +151,6 @@ QString formatInfo(const ListInfoData & list,  BtConstModuleList const & modules
             case Footnote:
                 text.append( decodeFootnote( (*it).second ) );
                 continue;
-            case WordTranslation:
-                text.append( getWordTranslation( (*it).second ) );
-                continue;
-            case WordGloss:
-                //text.append( getWordTranslation( (*it).second ) );
-                continue;
             case Abbreviation:
                 text.append( decodeAbbreviation( (*it).second ) );
                 continue;
@@ -191,13 +174,15 @@ QString formatInfo(const ListInfoData & list,  BtConstModuleList const & modules
                 }
                 else if ((*it).second.contains("sword:"))
                 {
-                    //text.append("Not implemented yet.");
+                    text.append( decodeSwordReference( (*it).second ) );
+                    continue;
                 }
                 else
                     BT_ASSERT(false); /// \todo Why is this here?
+                Q_FALLTHROUGH();
             default:
                 continue;
-        };
+        }
     }
 
     return formatInfo(text);
@@ -268,10 +253,10 @@ QString decodeCrossReference(QString const & data, BtConstModuleList const & mod
         module = modules.at(0);
 
     // BT_ASSERT(module); // why? the existense of the module is tested later
-    CTextRendering::KeyTreeItem::Settings settings(
+    CTextRendering::KeyTreeItem::Settings settings{
         false,
         CTextRendering::KeyTreeItem::Settings::CompleteShort
-    );
+    };
 
     if (module && (module->type() == CSwordModuleInfo::Bible)) {
         sword::VerseKey vk;
@@ -326,7 +311,7 @@ QString decodeFootnote(QString const & data) {
     QStringList list = data.split("/");
     BT_ASSERT(list.count() >= 3);
     if (!list.count())
-        return QString::null;
+        return QString();
 
     FilterOptions filterOpts;
     filterOpts.footnotes   = true;
@@ -342,7 +327,7 @@ QString decodeFootnote(QString const & data) {
 
     CSwordModuleInfo * const module = CSwordBackend::instance()->findModuleByName(modulename);
     if (!module)
-        return QString::null;
+        return QString();
 
     QSharedPointer<CSwordKey> key(CSwordKey::createInstance(module));
     key->setKey(keyname);
@@ -365,23 +350,39 @@ QString decodeFootnote(QString const & data) {
            .arg(text);
 }
 
+CSwordModuleInfo * getFirstAvalibleStrongsModule (bool wantHebrew) {
+    Q_FOREACH(CSwordModuleInfo * m, CSwordBackend::instance()->moduleList()) {
+        if (m->type() == CSwordLexiconModuleInfo::Lexicon) {
+            auto lexModule = qobject_cast<CSwordLexiconModuleInfo *>(m);
+            if (wantHebrew && m->has(CSwordModuleInfo::HebrewDef) && lexModule->hasStrongsKeys())
+                return m;
+            if (! wantHebrew && m->has(CSwordModuleInfo::GreekDef) && lexModule->hasStrongsKeys())
+                return m;
+        }
+    }
+    return nullptr;
+}
+
+CSwordModuleInfo *  getStrongsModule (bool wantHebrew) {
+    CSwordModuleInfo * module = btConfig().getDefaultSwordModuleByType(
+                wantHebrew ? "standardHebrewStrongsLexicon" : "standardGreekStrongsLexicon");
+    if (!module)
+        module = getFirstAvalibleStrongsModule(wantHebrew);
+    return module;
+}
+
 QString decodeStrongs(QString const & data) {
     QStringList strongs = data.split("|");
     QString ret;
 
     QStringList::const_iterator end = strongs.end();
     for (QStringList::const_iterator it = strongs.begin(); it != end; ++it) {
-        CSwordModuleInfo * const module = btConfig().getDefaultSwordModuleByType
-                                         (
-                                             ((*it).left(1) == QString("H")) ?
-                                             "standardHebrewStrongsLexicon" :
-                                             "standardGreekStrongsLexicon"
-                                         );
-
+        bool wantHebrew = (*it).left(1) == QString("H");
+        CSwordModuleInfo * module = getStrongsModule(wantHebrew);
         QString text;
         if (module) {
             QSharedPointer<CSwordKey> key(CSwordKey::createInstance(module));
-            auto lexModule = qobject_cast<CSwordLexiconModuleInfo*>(module);
+            auto lexModule = qobject_cast<CSwordLexiconModuleInfo *>(module);
             key->setKey(lexModule->normalizeStrongsKey(*it));
             text = key->renderedText();
         }
@@ -398,7 +399,6 @@ QString decodeStrongs(QString const & data) {
             .arg(text)
         );
     }
-
     return ret;
 }
 
@@ -479,15 +479,43 @@ QString decodeMorph(QString const & data) {
     return ret;
 }
 
+QString decodeSwordReference(QString const & data) {
+    QString moduleName;
+    QString reference;
+    QString text;
+    CSwordModuleInfo * module = nullptr;
+
+    QRegExp rx("sword://(bible|lexicon)/(.*)/(.*)", Qt::CaseInsensitive);
+    rx.setMinimal(false);
+    int pos1 = rx.indexIn(data);
+    if (pos1 > -1) {
+        moduleName = rx.cap(2);
+        reference = rx.cap(3);
+        module = CSwordBackend::instance()->findModuleByName(moduleName);
+        if (module) {
+            QSharedPointer<CSwordKey> key(CSwordKey::createInstance(module));
+            key->setKey(reference);
+            text = key->renderedText();
+        } else {
+            return "";
+        }
+    }
+
+    return QString("<div class=\"crossrefinfo\" lang=\"%1\"><h3>%2</h3><p>%3</p></div>")
+           .arg(module->language()->abbrev())
+           .arg(reference)
+           .arg(text);
+}
+
 QString getWordTranslation(QString const & data) {
     CSwordModuleInfo * const module = btConfig().getDefaultSwordModuleByType("standardLexicon");
     if (!module)
-        return QString::null;
+        return QString();
 
     QSharedPointer<CSwordKey> key(CSwordKey::createInstance(module));
     key->setKey(data);
     if (key->key().toUpper() != data.toUpper()) //key not present in the lexicon
-        return QString::null;
+        return QString();
 
     return QString("<div class=\"translationinfo\" lang=\"%1\"><h3>%2: %3</h3><p>%4</p></div>")
                   .arg(module->language()->abbrev())
