@@ -2,15 +2,15 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2016 by the BibleTime developers.
+* Copyright 1999-2020 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#include "frontend/btbookshelfdockwidget.h"
+#include "btbookshelfdockwidget.h"
 
 #include <QAction>
 #include <QActionGroup>
@@ -19,15 +19,15 @@
 #include <QPushButton>
 #include <QStackedWidget>
 #include <QVBoxLayout>
-#include "backend/managers/cswordbackend.h"
+#include "../backend/managers/cswordbackend.h"
+#include "../util/btassert.h"
+#include "../util/btconnect.h"
+#include "../util/cresmgr.h"
 #include "bibletime.h"
 #include "bibletimeapp.h"
-#include "frontend/btbookshelfview.h"
-#include "frontend/btbookshelfwidget.h"
-#include "frontend/messagedialog.h"
-#include "util/btassert.h"
-#include "util/btconnect.h"
-#include "util/cresmgr.h"
+#include "btbookshelfview.h"
+#include "btbookshelfwidget.h"
+#include "messagedialog.h"
 
 
 namespace {
@@ -127,19 +127,6 @@ void BtBookshelfDockWidget::initMenus() {
     m_itemActionGroup->addAction(m_itemSearchAction);
     m_itemContextMenu->addAction(m_itemSearchAction);
 
-    m_itemEditMenu = new QMenu(this);
-    m_itemEditMenu->setIcon(RM::editModuleMenu::icon());
-    m_itemContextMenu->addMenu(m_itemEditMenu);
-    m_itemEditPlainAction = new QAction(this);
-    m_itemEditPlainAction->setIcon(RM::editModulePlain::icon());
-    m_itemActionGroup->addAction(m_itemEditPlainAction);
-    m_itemEditMenu->addAction(m_itemEditPlainAction);
-
-    m_itemEditHtmlAction = new QAction(this);
-    m_itemEditHtmlAction->setIcon(RM::editModuleHTML::icon());
-    m_itemActionGroup->addAction(m_itemEditHtmlAction);
-    m_itemEditMenu->addAction(m_itemEditHtmlAction);
-
     m_itemUnlockAction = new QAction(this);
     m_itemUnlockAction->setIcon(RM::unlockModule::icon());
     m_itemActionGroup->addAction(m_itemUnlockAction);
@@ -158,9 +145,6 @@ void BtBookshelfDockWidget::retranslateUi() {
     setWindowTitle(tr("Bookshelf"));
 
     m_itemOpenAction->setText(tr("&Open"));
-    m_itemEditMenu->setTitle(tr("&Edit"));
-    m_itemEditPlainAction->setText(tr("&Plain text"));
-    m_itemEditHtmlAction->setText(tr("&HTML"));
     m_itemUnlockAction->setText(tr("&Unlock..."));
     m_itemAboutAction->setText(tr("&About..."));
 
@@ -212,12 +196,6 @@ void BtBookshelfDockWidget::slotItemActionTriggered(QAction *action) {
     else if (action == m_itemSearchAction) {
         emit moduleSearchTriggered(module);
     }
-    else if (action == m_itemEditPlainAction) {
-        emit moduleEditPlainTriggered(module);
-    }
-    else if (action == m_itemEditHtmlAction) {
-        emit moduleEditHtmlTriggered(module);
-    }
     else if (action == m_itemUnlockAction) {
         emit moduleUnlockTriggered(module);
     }
@@ -232,7 +210,6 @@ void BtBookshelfDockWidget::slotPrepareItemContextMenu() {
     m_itemOpenAction->setEnabled(!module->isLocked());
     m_itemSearchAction->setText(tr("&Search in %1...").arg(module->name()));
     m_itemSearchAction->setEnabled(!module->isLocked());
-    m_itemEditMenu->setEnabled(module->isWritable());
     m_itemUnlockAction->setEnabled(module->isLocked());
 }
 
@@ -249,3 +226,11 @@ void BtBookshelfDockWidget::slotGroupingOrderChanged(
     g.saveTo(groupingOrderKey);
     emit groupingOrderChanged(g);
 }
+
+void BtBookshelfDockWidget::loadBookshelfState() {
+    m_bookshelfWidget->loadBookshelfState();
+}
+
+void BtBookshelfDockWidget::saveBookshelfState() {
+    m_bookshelfWidget->saveBookshelfState();
+}
