@@ -2,9 +2,9 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2016 by the BibleTime developers.
+* Copyright 1999-2020 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -15,8 +15,8 @@
 
 #include <QDockWidget>
 
-#include "backend/bookshelfmodel/btbookshelftreemodel.h"
-#include "frontend/btbookshelfwidget.h"
+#include "../backend/bookshelfmodel/btbookshelftreemodel.h"
+#include "btbookshelfwidget.h"
 
 
 class QAction;
@@ -37,12 +37,13 @@ class BtBookshelfDockWidget: public QDockWidget {
             return m_treeModel->groupingOrder();
         }
 
+        void loadBookshelfState();
+        void saveBookshelfState();
+
     signals:
         void moduleHovered(CSwordModuleInfo *module);
         void moduleOpenTriggered(CSwordModuleInfo *module);
         void moduleSearchTriggered(CSwordModuleInfo *module);
-        void moduleEditPlainTriggered(CSwordModuleInfo *module);
-        void moduleEditHtmlTriggered(CSwordModuleInfo *module);
         void moduleUnlockTriggered(CSwordModuleInfo *module);
         void moduleAboutTriggered(CSwordModuleInfo *module);
         void groupingOrderChanged(BtBookshelfTreeModel::Grouping newGrouping);
@@ -73,9 +74,6 @@ class BtBookshelfDockWidget: public QDockWidget {
         QActionGroup *m_itemActionGroup;
         QAction *m_itemOpenAction;
         QAction *m_itemSearchAction;
-        QMenu   *m_itemEditMenu;
-        QAction *m_itemEditPlainAction;
-        QAction *m_itemEditHtmlAction;
         QAction *m_itemUnlockAction;
         QAction *m_itemAboutAction;
 
