@@ -2,9 +2,9 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2016 by the BibleTime developers.
+* Copyright 1999-2020 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -15,7 +15,7 @@
 
 #include <QWidget>
 
-#include <backend/bookshelfmodel/btbookshelftreemodel.h>
+#include "../backend/bookshelfmodel/btbookshelftreemodel.h"
 
 
 class BtBookshelfFilterModel;
@@ -70,10 +70,15 @@ class BtBookshelfWidget: public QWidget {
 
         bool eventFilter(QObject *object, QEvent *event) override;
 
+        void loadBookshelfState();
+        void saveBookshelfState();
+
     protected:
+        void findExpanded(const QModelIndex& index, QString prefix, QStringList * expandedPaths);
         void initActions();
         void initMenus();
         void initWidgets();
+        void restoreExpanded(const QModelIndex& index, const QStringList& nodeList);
         void retranslateUi();
 
     protected slots:
