@@ -2,23 +2,30 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2016 by the BibleTime developers.
+* Copyright 1999-2020 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#include "frontend/btmenuview.h"
+#include "btmenuview.h"
 
 #include <QActionGroup>
-#include "util/btassert.h"
-#include "util/btconnect.h"
+#include "../util/btassert.h"
+#include "../util/btconnect.h"
 
 
-BtMenuView::BtMenuView(QWidget *parent)
-    : QMenu(parent), m_model(nullptr), m_parentIndex(QModelIndex()), m_actions(nullptr)
+BtMenuView::BtMenuView(QWidget * parent)
+    : BtMenuView(QString(), parent)
+{}
+
+BtMenuView::BtMenuView(QString const & title, QWidget * parent)
+    : QMenu(title, parent)
+    , m_model(nullptr)
+    , m_parentIndex(QModelIndex())
+    , m_actions(nullptr)
 {
     BT_CONNECT(this, SIGNAL(aboutToShow()),
                this, SLOT(slotAboutToShow()));
@@ -43,11 +50,11 @@ void BtMenuView::setParentIndex(const QModelIndex &parentIndex) {
     m_parentIndex = parentIndex;
 }
 
-void BtMenuView::preBuildMenu() {
+void BtMenuView::preBuildMenu(QActionGroup *) {
     // Intentionally empty. Reimplement in subclass if needed.
 }
 
-void BtMenuView::postBuildMenu() {
+void BtMenuView::postBuildMenu(QActionGroup *) {
     // Intentionally empty. Reimplement in subclass if needed.
 }
 
@@ -176,18 +183,15 @@ void BtMenuView::slotAboutToShow() {
     // leads to executing a deleted action and a crash. It is much safer
     // to remove the menus here.
     removeMenus();
-    delete m_actions;
-    m_actions = nullptr;
     m_indexMap.clear();
 
-    preBuildMenu();
-
-    if (m_model != nullptr) {
-        m_actions = new QActionGroup(this);
+    delete m_actions;
+    m_actions = m_model ? new QActionGroup(this) : nullptr;
 
+    preBuildMenu(m_actions);
+    if (m_model)
         buildMenu(this, m_parentIndex);
-    }
-    postBuildMenu();
+    postBuildMenu(m_actions);
 }
 
 void BtMenuView::removeMenus() {
