@@ -2,9 +2,9 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2016 by the BibleTime developers.
+* Copyright 1999-2020 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -44,7 +44,8 @@ class QActionGroup;
 class BtMenuView: public QMenu {
     Q_OBJECT
     public:
-        BtMenuView(QWidget *parent = nullptr);
+        BtMenuView(QWidget * parent = nullptr);
+        BtMenuView(QString const & title, QWidget * parent = nullptr);
         virtual ~BtMenuView();
 
         /**
@@ -98,7 +99,7 @@ class BtMenuView: public QMenu {
           is unset after this method returns, the menu is not populated with data from the
           item model.
         */
-        virtual void preBuildMenu();
+        virtual void preBuildMenu(QActionGroup * actions);
 
         /**
           This method is called by BtMenuView after populating itself with data from the
@@ -106,7 +107,7 @@ class BtMenuView: public QMenu {
           Reimplement this method to add any menus/actions to this menu after the items of
           the menu. The default implementation does nothing.
         */
-        virtual void postBuildMenu();
+        virtual void postBuildMenu(QActionGroup * actions);
 
         /**
           This method is called by BtMenuView to initialize an action to add to this menu. If
@@ -136,11 +137,13 @@ class BtMenuView: public QMenu {
         void slotAboutToShow();
         void slotActionTriggered(QAction *action);
 
-    protected:
+    private: /* Fields: */
+
         QAbstractItemModel *m_model;
         QPersistentModelIndex m_parentIndex;
         QActionGroup *m_actions;
         QMap<QAction *, QPersistentModelIndex> m_indexMap;
+
 };
 
 #endif // BTMENUVIEW_H
