@@ -2,9 +2,9 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2014 by the BibleTime developers.
+* Copyright 1999-2020 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -15,7 +15,7 @@
 
 #include <QDialog>
 
-#include "frontend/btbookshelfwidget.h"
+#include "btbookshelfwidget.h"
 
 
 class CSwordModuleInfo;
@@ -26,7 +26,7 @@ class BtModuleChooserDialog : public QDialog {
     Q_OBJECT
 
     protected:
-        explicit BtModuleChooserDialog(QWidget *parent = 0, Qt::WindowFlags flags = 0);
+        explicit BtModuleChooserDialog(QWidget *parent = nullptr, Qt::WindowFlags flags = nullptr);
 
         void retranslateUi();
 
