@@ -2,10 +2,11 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
@@ -16,14 +17,14 @@
 
 #include <QList>
 #include <QPair>
-#include "backend/rendering/btinforendering.h"
+#include "../backend/rendering/btinforendering.h"
 
 
 class CReadDisplay;
 class QAction;
 class QSize;
 class BibleTime;
-
+class QTextBrowser;
 
 namespace InfoDisplay {
 
@@ -41,6 +42,7 @@ public: /* Methods: */
     void setInfo(Rendering::InfoType const, QString const & data);
     void setInfo(Rendering::ListInfoData const &);
     QSize sizeHint() const override;
+    void updateColors();
 
 public slots:
 
@@ -48,12 +50,17 @@ public slots:
 
 private slots:
 
-    void lookupInfo(const QString &, const QString &);
+    void lookupInfo(const QUrl &);
     void selectAll();
+    void slotContextMenu(const QPoint& point);
+
+private:
+    void setBrowserFont(const CSwordModuleInfo* const module);
 
 private: /* Fields: */
 
     CReadDisplay * m_htmlPart;
+    QTextBrowser * m_textBrowser;
     BibleTime * m_mainWindow;
 
 };
