@@ -1,18 +1,21 @@
 /*********
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
+*
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
-#include "frontend/display/btfontsizewidget.h"
+#include "btfontsizewidget.h"
 
 #include <QCompleter>
 #include <QFontDatabase>
 #include <QValidator>
-#include "util/btconnect.h"
+#include "../../util/btconnect.h"
 
 
 BtFontSizeWidget::BtFontSizeWidget(QWidget * parent)
