@@ -1,23 +1,26 @@
 /*********
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
+*
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
-#include "frontend/displaywindow/btdisplaysettingsbutton.h"
+#include "btdisplaysettingsbutton.h"
 
 #include <QHash>
 #include <QMenu>
 #include <QString>
 #include <QToolTip>
 #include <QToolButton>
-#include "bibletimeapp.h"
-#include "util/btassert.h"
-#include "util/btconnect.h"
-#include "util/cresmgr.h"
+#include "../../util/btassert.h"
+#include "../../util/btconnect.h"
+#include "../../util/cresmgr.h"
+#include "../bibletimeapp.h"
 
 
 BtDisplaySettingsButton::BtDisplaySettingsButton(QWidget *parent)
@@ -66,9 +69,6 @@ void BtDisplaySettingsButton::initMenu() {
     m_popup = new QMenu(this);
     setMenu(m_popup);
 
-    m_lineBreakAction = new QAction(this);
-    m_lineBreakAction->setCheckable(true);
-
     m_verseNumbersAction = new QAction(this);
     m_verseNumbersAction->setCheckable(true);
 
@@ -101,7 +101,6 @@ void BtDisplaySettingsButton::initMenu() {
 }
 
 void BtDisplaySettingsButton::retranslateUi() {
-    m_lineBreakAction->setText(tr("Use linebreaks after each verse"));
     m_verseNumbersAction->setText(tr("Show verse numbers"));
     m_headingsAction->setText(tr("Show headings"));
     m_redWordsAction->setText(tr("Highlight words of Jesus"));
@@ -128,10 +127,8 @@ void BtDisplaySettingsButton::retranslateToolTip() {
 void BtDisplaySettingsButton::slotOptionToggled(QAction *action) {
     bool checked = action->isChecked();
 
-    if (action == m_lineBreakAction) {
-        m_displayOptions.lineBreaks = checked;
-        emit sigDisplayOptionsChanged(m_displayOptions);
-    } else if (action == m_verseNumbersAction) {
+
+    if (action == m_verseNumbersAction) {
         m_displayOptions.verseNumbers = checked;
         emit sigDisplayOptionsChanged(m_displayOptions);
     } else if (action == m_variantAction) {
@@ -176,7 +173,6 @@ void BtDisplaySettingsButton::repopulateMenu() {
     m_popup->clear();
     if (!m_modules.isEmpty()) {
         if (m_modules.first()->type() == CSwordModuleInfo::Bible) {
-            addMenuEntry(m_lineBreakAction, m_displayOptions.lineBreaks);
             addMenuEntry(m_verseNumbersAction, m_displayOptions.verseNumbers);
             enable = true;
         }
