@@ -2,10 +2,11 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2014 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
@@ -26,16 +27,15 @@ class BtToolBarPopupAction : public QWidgetAction {
     public:
 
         BtToolBarPopupAction(const QIcon& icon, const QString& text, QObject* parent);
-        ~BtToolBarPopupAction();
+        ~BtToolBarPopupAction() override;
 
 // return the QMenu object so a popup menu can be constructed
         QMenu* popupMenu() const;
 
-// Function to catch the Shortcut event and emit the triggered signal
-        virtual bool event(QEvent* e);
+        bool event(QEvent* e) override;
 
     protected:
-        QWidget* createWidget(QWidget* parent);
+        QWidget* createWidget(QWidget* parent) override;
 
     private slots:
 
