@@ -1,13 +1,16 @@
 /*********
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
+*
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
-#include "frontend/displaywindow/cbiblereadwindow.h"
+#include "cbiblereadwindow.h"
 
 #include <QAction>
 #include <QEvent>
@@ -15,26 +18,27 @@
 #include <QMenu>
 #include <QTimer>
 #include <QWidget>
-#include "backend/drivers/cswordbiblemoduleinfo.h"
-#include "backend/keys/cswordversekey.h"
-#include "bibletimeapp.h"
-#include "frontend/cexportmanager.h"
-#include "frontend/cmdiarea.h"
-#include "frontend/display/creaddisplay.h"
-#include "frontend/displaywindow/btactioncollection.h"
-#include "frontend/displaywindow/ccommentaryreadwindow.h"
-#include "frontend/displaywindow/btdisplaysettingsbutton.h"
-#include "frontend/keychooser/ckeychooser.h"
-#include "util/btassert.h"
-#include "util/btconnect.h"
-#include "util/directory.h"
-#include "util/cresmgr.h"
-#include "util/tool.h"
+#include "../../backend/drivers/cswordbiblemoduleinfo.h"
+#include "../../backend/keys/cswordversekey.h"
+#include "../../util/btassert.h"
+#include "../../util/btconnect.h"
+#include "../../util/directory.h"
+#include "../../util/cresmgr.h"
+#include "../../util/tool.h"
+#include "../bibletimeapp.h"
+#include "../cexportmanager.h"
+#include "../cmdiarea.h"
+#include "../display/creaddisplay.h"
+#include "../keychooser/ckeychooser.h"
+#include "btactioncollection.h"
+#include "btdisplaysettingsbutton.h"
+#include "ccommentaryreadwindow.h"
 
 
 void CBibleReadWindow::applyProfileSettings(const QString & windowGroup) {
     CLexiconReadWindow::applyProfileSettings(windowGroup);
 
+    setObjectName("CBibleReadWindow");
     BtConfig & conf = btConfig();
     conf.beginGroup(windowGroup);
     filterOptions() = conf.getFilterOptions();
@@ -101,13 +105,13 @@ void CBibleReadWindow::insertKeyboardActions( BtActionCollection* const a ) {
     qaction->setShortcut(QKeySequence::Print);
     a->addAction("printChapter", qaction);
 
-//    qaction = new QAction( /* QIcon(CResMgr::displaywindows::general::findStrongs::icon), */ tr("Strong's search"), a);
-//    qaction->setShortcut(CResMgr::displaywindows::general::findStrongs::accel);
-//    qaction->setToolTip(tr("Find all occurences of the Strong number currently under the mouse cursor"));
-//    a->addAction(CResMgr::displaywindows::general::findStrongs::actionName, qaction);
+    //    qaction = new QAction( /* QIcon(CResMgr::displaywindows::general::findStrongs::icon), */ tr("Strong's search"), a);
+    //    qaction->setShortcut(CResMgr::displaywindows::general::findStrongs::accel);
+    //    qaction->setToolTip(tr("Find all occurences of the Strong number currently under the mouse cursor"));
+    //    a->addAction(CResMgr::displaywindows::general::findStrongs::actionName, qaction);
 
-//    qaction = new QAction(tr("Reference only"), a );
-//    a->addAction("copyReferenceOnly", qaction);
+    //    qaction = new QAction(tr("Reference only"), a );
+    //    a->addAction("copyReferenceOnly", qaction);
 
     qaction = new QAction(tr("Text of reference"), a);
     a->addAction("copyTextOfReference", qaction);
@@ -127,7 +131,7 @@ void CBibleReadWindow::initActions() {
 
     CLexiconReadWindow::initActions(); //make sure the predefined actions are available
 
-    CBibleReadWindow::insertKeyboardActions(ac);
+    insertKeyboardActions(ac);
 
     ac->action("nextEntry").setEnabled(false);
     ac->action("previousEntry").setEnabled(false);
@@ -139,7 +143,6 @@ void CBibleReadWindow::initActions() {
     initAction("nextVerse", this, &CBibleReadWindow::nextVerse);
     initAction("previousVerse", this, &CBibleReadWindow::previousVerse);
 
-    m_actions.selectAll = &ac->action("selectAll");
     m_actions.findText = &ac->action("findText");
     m_actions.findStrongs = &ac->action(CResMgr::displaywindows::general::findStrongs::actionName);
     m_actions.copy.referenceOnly = &ac->action("copyReferenceOnly");
@@ -161,6 +164,8 @@ void CBibleReadWindow::initActions() {
 
     m_actions.copy.selectedText = &ac->action("copySelectedText");
 
+    m_actions.copy.byReferences = &ac->action("copyByReferences");
+
     m_actions.save.referenceAndText =
             &initAction("saveReferenceWithText",
                         displayWidget()->connectionsProxy(),
@@ -209,19 +214,21 @@ void CBibleReadWindow::setupPopupMenu() {
     QKeySequence ks = m_actions.findText->shortcut();
     QString keys = ks.toString();
     popup()->addAction(m_actions.findStrongs);
-    popup()->addAction(m_actions.selectAll);
 
     popup()->addSeparator();
 
-    m_actions.copyMenu = new QMenu(tr("Copy..."), popup());
+    m_actions.copyMenu = new QMenu(tr("Copy"), popup());
+
+    m_actions.copyMenu->addSeparator();
+
+    m_actions.copyMenu->addAction(m_actions.copy.selectedText);
+    m_actions.copyMenu->addAction(m_actions.copy.byReferences);
     m_actions.copyMenu->addAction(m_actions.copy.referenceOnly);
     m_actions.copyMenu->addAction(m_actions.copy.referenceTextOnly);
     m_actions.copyMenu->addAction(m_actions.copy.referenceAndText);
     m_actions.copyMenu->addAction(m_actions.copy.chapter);
 
-    m_actions.copyMenu->addSeparator();
 
-    m_actions.copyMenu->addAction(m_actions.copy.selectedText);
     popup()->addMenu(m_actions.copyMenu);
 
     m_actions.saveMenu = new QMenu(tr("Save..."), popup());
@@ -245,7 +252,6 @@ void CBibleReadWindow::setupPopupMenu() {
 
 /** Reimplemented. */
 void CBibleReadWindow::updatePopupMenu() {
-    qWarning("CBibleReadWindow::updatePopupMenu()");
 
     CReadDisplay const & display =
             *static_cast<CReadDisplay *>(displayWidget());
@@ -255,11 +261,12 @@ void CBibleReadWindow::updatePopupMenu() {
     m_actions.copy.referenceOnly->setEnabled(hasActiveAnchor);
     m_actions.copy.referenceTextOnly->setEnabled(hasActiveAnchor);
     m_actions.copy.referenceAndText->setEnabled(hasActiveAnchor);
-    m_actions.copy.selectedText->setEnabled(display.hasSelection());
 
     m_actions.save.referenceAndText->setEnabled(hasActiveAnchor);
 
     m_actions.print.reference->setEnabled(hasActiveAnchor);
+
+    m_actions.copy.selectedText->setEnabled(hasSelectedText());
 }
 
 /** Moves to the next book. */
@@ -344,7 +351,7 @@ void CBibleReadWindow::saveChapterHTML() {
     vk.setUpperBound(dummy);
 
     CExportManager mgr(true, tr("Saving"), filterOptions(), displayOptions());
-    mgr.saveKey(&vk, CExportManager::HTML, true);
+    mgr.saveKey(&vk, CExportManager::HTML, true, modules());
 }
 
 /** Saves the chapter as valid HTML page. */
@@ -362,7 +369,7 @@ void CBibleReadWindow::saveChapterPlain() {
     vk.setUpperBound(dummy);
 
     CExportManager mgr(true, tr("Saving"), filterOptions(), displayOptions());
-    mgr.saveKey(&vk, CExportManager::Text, true);
+    mgr.saveKey(&vk, CExportManager::Text, true, modules());
 }
 
 void CBibleReadWindow::reload(CSwordBackend::SetupChangedReason reason) {
