@@ -2,20 +2,21 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
 #ifndef CREADWINDOW_H
 #define CREADWINDOW_H
 
-#include "frontend/displaywindow/cdisplaywindow.h"
+#include "cdisplaywindow.h"
 
-#include "frontend/display/cdisplay.h"
-#include "frontend/display/creaddisplay.h"
+#include "../display/cdisplay.h"
+#include "../display/creaddisplay.h"
 
 
 class BtActionCollection;
@@ -30,12 +31,6 @@ public: /* Methods: */
 
     CReadWindow(QList<CSwordModuleInfo *> modules, CMDIArea * parent);
 
-    /**
-       Inserts the keyboard accelerators of this window into the given
-       collection.
-    */
-    static void insertKeyboardActions(BtActionCollection * const a);
-
     virtual CSwordModuleInfo::ModuleType moduleType() const = 0;
 
 protected: /* Methods: */
@@ -44,6 +39,17 @@ protected: /* Methods: */
 
     void resizeEvent(QResizeEvent * e) override;
 
+    void pageDown() override;
+
+    void pageUp() override;
+
+    void copySelectedText() override;
+
+    void copyByReferences() override;
+
+    bool hasSelectedText() override;
+
+
 protected slots:
 
     void lookupSwordKey(CSwordKey *) override;
@@ -60,6 +66,8 @@ protected slots:
     /** Opens the search dialog with the strong info of the last clicked word.*/
     void openSearchStrongsDialog();
 
+    void colorThemeChangedSlot();
+
 private: /* Fields: */
 
     CReadDisplay * m_readDisplayWidget;
