@@ -1,24 +1,27 @@
 /*********
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
+*
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
-#include "frontend/keychooser/cbookkeychooser.h"
+#include "cbookkeychooser.h"
 
 #include <QDebug>
 #include <QHBoxLayout>
 #include <QList>
 #include <QWidget>
-#include "backend/config/btconfig.h"
-#include "backend/drivers/cswordbookmoduleinfo.h"
-#include "backend/keys/cswordtreekey.h"
-#include "frontend/keychooser/bthistory.h"
-#include "util/btassert.h"
-#include "util/btconnect.h"
+#include "../../backend/config/btconfig.h"
+#include "../../backend/drivers/cswordbookmoduleinfo.h"
+#include "../../backend/keys/cswordtreekey.h"
+#include "../../util/btassert.h"
+#include "../../util/btconnect.h"
+#include "bthistory.h"
 
 
 #define ID_PROPERTY_NAME "CBookKeyChooser_ID"
@@ -224,7 +227,7 @@ void CBookKeyChooser::setupCombo(const QString & key,
 
     QStringList items;
     if (depth > 0)
-        items.append(QString::null); // Insert an empty item at the top
+        items.append(QString()); // Insert an empty item at the top
 
     do {
         items.append(tmpKey.getLocalNameUnicode());
