@@ -1,13 +1,16 @@
 /*********
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
+*
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
-#include "frontend/keychooser/ckeychooserwidget.h"
+#include "ckeychooserwidget.h"
 
 #include <QComboBox>
 #include <QFocusEvent>
@@ -15,8 +18,8 @@
 #include <QLineEdit>
 #include <QString>
 #include <QWheelEvent>
-#include "frontend/keychooser/cscrollerwidgetset.h"
-#include "util/btconnect.h"
+#include "../../util/btconnect.h"
+#include "cscrollerwidgetset.h"
 
 
 class BtKeyLineEdit : public QLineEdit {
@@ -82,21 +85,6 @@ bool CKCComboBox::eventFilter(QObject * o, QEvent * e) {
     return QComboBox::eventFilter(o, e);
 }
 
-/** Scrolls in the list if the wheel of the mouse was used. */
-void CKCComboBox::wheelEvent(QWheelEvent * e) {
-    return QComboBox::wheelEvent(e); /// \bug rest method won't get executed.
-
-    int const change = static_cast<int>(static_cast<float>(e->delta()) / 120);
-    int current = currentIndex();
-
-    if ((current + change >= 0) && (current + change < count()) ) {
-        setCurrentIndex(current + change);
-        e->accept();
-        emit activated(currentIndex());
-    } else {
-        e->ignore();
-    }
-}
 
 //**********************************************************************************/
 
@@ -152,7 +140,7 @@ void CKeyChooserWidget::reset(const QStringList * list, int index, bool do_emit)
     //  qWarning("starting insert");
     m_isResetting = true;
 
-    m_oldKey = QString::null;
+    m_oldKey = QString();
 
     //  m_comboBox->setUpdatesEnabled(false);
     //DON'T REMOVE THE HIDE: Otherwise QComboBox's sizeHint() function won't work properly
@@ -182,14 +170,14 @@ void CKeyChooserWidget::reset(const QStringList * list, int index, bool do_emit)
 
 /** Initializes this widget. We need this function because we have more than one constructor. */
 void CKeyChooserWidget::init() {
-    m_oldKey = QString::null;
+    m_oldKey = QString();
 
     setFocusPolicy(Qt::WheelFocus);
 
     m_comboBox = new CKCComboBox(this);
     setFocusProxy(m_comboBox);
-    m_comboBox->setAutoCompletion(true);
-    m_comboBox->setEditable(true);
+    m_comboBox->setEditable(true); // Also sets completer
+    BT_ASSERT(m_comboBox->completer());
     m_comboBox->setInsertPolicy(QComboBox::NoInsert);
     m_comboBox->setFocusPolicy(Qt::WheelFocus);
 
