@@ -1,20 +1,23 @@
 /*********
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
+*
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
-#include "frontend/keychooser/cscrollerwidgetset.h"
+#include "cscrollerwidgetset.h"
 
 #include <QString>
 #include <QToolButton>
 #include <QVBoxLayout>
 #include <QWheelEvent>
-#include "frontend/keychooser/cscrollbutton.h"
-#include "util/btconnect.h"
+#include "../../util/btconnect.h"
+#include "cscrollbutton.h"
 
 
 #define WIDTH (static_cast<unsigned int>(16))
