@@ -2,10 +2,11 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2014 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
@@ -14,10 +15,7 @@
 
 #include <QDialog>
 
-#include "backend/cswordmodulesearch.h"
-
-// Sword includes
-#include <listkey.h>
+#include "../../../backend/cswordmodulesearch.h"
 
 
 class CSwordModuleInfo;
@@ -36,14 +34,14 @@ class CSearchAnalysisDialog : public QDialog {
         Q_OBJECT
     public:
         CSearchAnalysisDialog(const CSwordModuleSearch::Results &results,
-                              QWidget *parentDialog = 0);
+                              QWidget *parentDialog = nullptr);
 
     protected: // Protected methods
         /**
          * Initializes this dialog.
          */
         void initView();
-        void resizeEvent(QResizeEvent* event);
+        void resizeEvent(QResizeEvent* event) override;
 
     private slots:
         void buttonClicked(QAbstractButton* button);
