@@ -1,19 +1,22 @@
 /*********
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
+*
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
-#include "frontend/searchdialog/analysis/csearchanalysislegenditem.h"
+#include "csearchanalysislegenditem.h"
 
 #include <QFont>
 #include <QPainter>
 #include <QPen>
-#include "backend/drivers/cswordmoduleinfo.h"
-#include "frontend/searchdialog/analysis/csearchanalysisscene.h"
+#include "../../../backend/drivers/cswordmoduleinfo.h"
+#include "csearchanalysisscene.h"
 
 
 namespace Search {
