@@ -2,22 +2,22 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2016 by the BibleTime developers.
+* Copyright 1999-2020 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#include "frontend/searchdialog/btsearchmodulechooserdialog.h"
+#include "btsearchmodulechooserdialog.h"
 
 #include <QAction>
 #include <QToolButton>
-#include "backend/bookshelfmodel/btbookshelftreemodel.h"
-#include "backend/managers/cswordbackend.h"
-#include "util/btconnect.h"
-#include "util/tool.h"
+#include "../../backend/bookshelfmodel/btbookshelftreemodel.h"
+#include "../../backend/managers/cswordbackend.h"
+#include "../../util/btconnect.h"
+#include "../../util/tool.h"
 
 
 namespace {
@@ -49,7 +49,7 @@ BtSearchModuleChooserDialog::BtSearchModuleChooserDialog(QWidget *parent,
 
 void BtSearchModuleChooserDialog::retranslateUi() {
     setWindowTitle(tr("Works to Search in"));
-    util::tool::initExplanationLabel(label(), QString::null,
+    util::tool::initExplanationLabel(label(), QString(),
                                      tr("Select the works which should be searched."));
 }
 
