@@ -2,9 +2,9 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2016 by the BibleTime developers.
+* Copyright 1999-2020 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -13,10 +13,10 @@
 #ifndef BTSEARCHMODULECHOOSERDIALOG_H
 #define BTSEARCHMODULECHOOSERDIALOG_H
 
-#include "frontend/btmodulechooserdialog.h"
+#include "../btmodulechooserdialog.h"
 
-#include "backend/drivers/btconstmoduleset.h"
-#include "backend/bookshelfmodel/btbookshelftreemodel.h"
+#include "../../backend/drivers/btconstmoduleset.h"
+#include "../../backend/bookshelfmodel/btbookshelftreemodel.h"
 
 
 class BtBookshelfTreeModel;
