@@ -1,13 +1,16 @@
 /*********
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
+*
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
-#include "frontend/searchdialog/btsearchresultarea.h"
+#include "btsearchresultarea.h"
 
 #include <QApplication>
 #include <QFrame>
@@ -17,18 +20,19 @@
 #include <QSize>
 #include <QSplitter>
 #include <QStringList>
+#include <QTextBrowser>
 #include <QVBoxLayout>
 #include <QWidget>
-#include "backend/keys/cswordversekey.h"
-#include "backend/rendering/cdisplayrendering.h"
-#include "backend/config/btconfig.h"
-#include "frontend/display/bthtmlreaddisplay.h"
-#include "frontend/searchdialog/cmoduleresultview.h"
-#include "frontend/searchdialog/csearchdialog.h"
-#include "frontend/searchdialog/csearchresultview.h"
-#include "util/btassert.h"
-#include "util/btconnect.h"
-#include "util/tool.h"
+#include "../../backend/config/btconfig.h"
+#include "../../backend/managers/colormanager.h"
+#include "../../backend/keys/cswordversekey.h"
+#include "../../backend/rendering/cdisplayrendering.h"
+#include "../../util/btassert.h"
+#include "../../util/btconnect.h"
+#include "../../util/tool.h"
+#include "cmoduleresultview.h"
+#include "csearchdialog.h"
+#include "csearchresultview.h"
 
 
 namespace {
@@ -83,26 +87,36 @@ void BtSearchResultArea::initView() {
 
     QVBoxLayout* frameLayout = new QVBoxLayout(m_displayFrame);
     frameLayout->setContentsMargins(0, 0, 0, 0);
-    m_previewDisplay = new BtHtmlReadDisplay(nullptr, m_displayFrame);
-    m_previewDisplay->view()->setToolTip(tr("Text of the selected search result item"));
-    frameLayout->addWidget(m_previewDisplay->view());
+    m_previewDisplay = new QTextBrowser(this);
+    m_previewDisplay->setOpenLinks(false);
+    m_previewDisplay->setToolTip(tr("Text of the selected search result item"));
+    frameLayout->addWidget(m_previewDisplay);
 
-    QAction* selectAllAction = new QAction(QIcon(), tr("Select all"), this);
-    selectAllAction->setShortcut(QKeySequence::SelectAll);
-    BT_CONNECT(selectAllAction, SIGNAL(triggered()), this, SLOT(selectAll()));
-
-    QAction* copyAction = new QAction(tr("Copy"), this);
-    copyAction->setShortcut( QKeySequence(Qt::CTRL + Qt::Key_C) );
-    BT_CONNECT(copyAction, SIGNAL(triggered()), this, SLOT(copySelection()));
-
-    QMenu* menu = new QMenu();
-    menu->addAction(selectAllAction);
-    menu->addAction(copyAction);
-    m_previewDisplay->installPopup(menu);
+    m_previewDisplay->setContextMenuPolicy(Qt::CustomContextMenu);
+    BT_CONNECT(m_previewDisplay, SIGNAL(customContextMenuRequested(const QPoint&)),
+        this, SLOT(slotContextMenu(const QPoint&)));
 
     loadDialogSettings();
 }
 
+void BtSearchResultArea::slotContextMenu(const QPoint& /* point */ ) {
+
+    QAction selectAllAction(tr("Select all"));
+    selectAllAction.setShortcut(QKeySequence::SelectAll);
+    BT_CONNECT(&selectAllAction, SIGNAL(triggered()),
+               this,            SLOT(selectAll()));
+
+    QAction copyAction(tr("Copy"));
+    copyAction.setShortcut(QKeySequence(Qt::CTRL + Qt::Key_C));
+    BT_CONNECT(&copyAction,                     SIGNAL(triggered()),
+               m_previewDisplay, SLOT(copy()));
+
+    QMenu menu;
+    menu.addAction(&selectAllAction);
+    menu.addAction(&copyAction);
+    menu.exec(QCursor::pos());
+}
+
 void BtSearchResultArea::setSearchResult(
         const CSwordModuleSearch::Results &results)
 {
@@ -209,8 +223,23 @@ void BtSearchResultArea::updatePreview(const QString& key) {
             text = render.renderSingleKey(key, modules, settings);
         }
 
-        m_previewDisplay->setText( CSwordModuleSearch::highlightSearchedText(text, searchedText) );
-        m_previewDisplay->moveToAnchor( CDisplayRendering::keyToHTMLAnchor(key) );
+        if (modules.count() > 0)
+            setBrowserFont(modules.at(0));
+
+        QString text2 = CSwordModuleSearch::highlightSearchedText(text, searchedText);
+        text2.replace("#CHAPTERTITLE#", "");
+        text2 = ColorManager::instance().replaceColors(text2);
+        m_previewDisplay->setText(text2);
+        m_previewDisplay->scrollToAnchor( CDisplayRendering::keyToHTMLAnchor(key) );
+    }
+}
+
+void BtSearchResultArea::setBrowserFont(const CSwordModuleInfo* const module) {
+    if (module) {
+            const CLanguageMgr::Language* lang = module->language();
+            m_previewDisplay->setFont(btConfig().getFontForLanguage(*lang).second);
+    } else {
+        m_previewDisplay->setFont(btConfig().getDefaultFont());
     }
 }
 
@@ -226,7 +255,7 @@ void BtSearchResultArea::initConnections() {
                SLOT(setupTree(CSwordModuleInfo const *,
                               sword::ListKey const &)));
     BT_CONNECT(m_moduleListBox,                      SIGNAL(moduleChanged()),
-               m_previewDisplay->connectionsProxy(), SLOT(clear()));
+               m_previewDisplay, SLOT(clear()));
 
     // connect the strongs list
     BT_CONNECT(m_moduleListBox,
@@ -356,7 +385,7 @@ QString StrongsResultList::getStrongsNumberText(const QString &verseContent,
             index += 6; // 6 is the length of "lemma="
         }
     }
-    return QString::null;
+    return QString();
 }
 
 
