@@ -2,10 +2,11 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
@@ -15,11 +16,12 @@
 #include <QList>
 #include <QSplitter>
 #include <QStringList>
+#include <QTextBrowser>
 #include <QWidget>
-#include "backend/managers/cswordbackend.h"
-#include "backend/cswordmodulesearch.h"
-#include "frontend/display/creaddisplay.h"
-#include "frontend/searchdialog/analysis/csearchanalysisdialog.h"
+#include "../../backend/managers/cswordbackend.h"
+#include "../../backend/cswordmodulesearch.h"
+#include "../display/creaddisplay.h"
+#include "analysis/csearchanalysisdialog.h"
 
 
 namespace Search {
@@ -96,7 +98,7 @@ class BtSearchResultArea : public QWidget {
         Q_OBJECT
     public: /* Methods: */
         BtSearchResultArea(QWidget *parent = nullptr);
-        inline ~BtSearchResultArea() { saveDialogSettings(); }
+        inline ~BtSearchResultArea() override { saveDialogSettings(); }
 
         /**
         * Sets the modules which contain the result of each.
@@ -139,6 +141,8 @@ class BtSearchResultArea : public QWidget {
         */
         void saveDialogSettings() const;
 
+        void setBrowserFont(const CSwordModuleInfo* const module);
+
     protected slots:
         /**
         * Update the preview of the selected key.
@@ -166,9 +170,11 @@ class BtSearchResultArea : public QWidget {
         * Copy selected text
         */
         inline void copySelection() {
-            m_previewDisplay->connectionsProxy()->copySelection();
+            m_previewDisplay->copy();
         }
 
+        void slotContextMenu(const QPoint& point);
+
     private: /* Fields: */
         CSwordModuleSearch::Results m_results;
 
@@ -176,7 +182,7 @@ class BtSearchResultArea : public QWidget {
         CSearchResultView* m_resultListBox;
 
         QFrame *m_displayFrame;
-        CReadDisplay* m_previewDisplay;
+        QTextBrowser* m_previewDisplay;
 
         QSplitter *m_mainSplitter;
         QSplitter *m_resultListSplitter;
