@@ -2,10 +2,11 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
@@ -15,9 +16,9 @@
 #include <QDialog>
 
 #include <QString>
-#include "backend/cswordmodulesearch.h"
-#include "backend/managers/cswordbackend.h"
-#include "frontend/searchdialog/btsearchoptionsarea.h"
+#include "../../backend/cswordmodulesearch.h"
+#include "../../backend/managers/cswordbackend.h"
+#include "btsearchoptionsarea.h"
 
 namespace Search {
 class BtSearchResultArea;
@@ -34,7 +35,7 @@ class CSearchDialog : public QDialog {
         Q_OBJECT
     public:
         static void openDialog(const BtConstModuleList modules,
-                               const QString &searchText = QString::null,
+                               const QString &searchText = QString(),
                                QWidget *parentDialog = nullptr);
 
         static void closeDialog();
@@ -121,10 +122,13 @@ class CSearchDialog : public QDialog {
         */
         void initConnections();
 
+        void manageIndexesButtonClicked();
+
         void closeButtonClicked();
 
     private:
         QPushButton* m_analyseButton;
+        QPushButton* m_manageIndexes;
         QPushButton* m_closeButton;
         BtSearchResultArea* m_searchResultArea;
         BtSearchOptionsArea* m_searchOptionsArea;
