@@ -1,13 +1,16 @@
 /*********
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
+*
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
-#include "frontend/settingsdialogs/btfontchooserwidget.h"
+#include "btfontchooserwidget.h"
 
 #include <QFontDatabase>
 #include <QFrame>
@@ -15,29 +18,13 @@
 #include <QLabel>
 #include <QListWidget>
 #include <QListWidgetItem>
-#include "frontend/btwebengineview.h"
-#include "frontend/settingsdialogs/clistwidget.h"
-#include "util/btconnect.h"
+#include <QTextBrowser>
+#include "../../util/btconnect.h"
+#include "clistwidget.h"
 
 
 namespace {
 
-class BtFontPreviewWebView: public BtWebEngineView {
-
-    public: /* Methods: */
-
-        inline BtFontPreviewWebView(QWidget *parent = nullptr)
-            : BtWebEngineView(parent)
-        {
-            setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
-        }
-
-        inline QSize sizeHint() const override {
-            return QSize(100, 100);
-        }
-
-};
-
 const QString DEFAULT_FONT_PREVIEW_TEXT =
     "1 In the beginning God created the heaven and the earth. "
     "2 And the earth was without form, and void; and darkness was on the face of the deep. "
@@ -80,7 +67,7 @@ void BtFontChooserWidget::createLayout() {
     m_sizeListWidget->setMinimumHeight(50);
     m_sizeListWidget->setCharWidth(5);
 
-    m_fontPreview = new BtFontPreviewWebView(this);
+    m_fontPreview = new QTextBrowser(this);
 
     QGridLayout *l = new QGridLayout;
     l->addWidget(m_fontNameLabel, 0, 0);
