@@ -2,10 +2,11 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
@@ -22,7 +23,7 @@ class CListWidget;
 class QListWidget;
 class QListWidgetItem;
 class QString;
-class BtWebEngineView;
+class QTextBrowser;
 
 class BtFontChooserWidget : public QFrame {
 
@@ -71,7 +72,7 @@ class BtFontChooserWidget : public QFrame {
         QLabel *m_fontSizeLabel;
             CListWidget *m_sizeListWidget;
 
-        BtWebEngineView *m_fontPreview;
+        QTextBrowser *m_fontPreview;
 
         QString m_htmlText;
         QFont m_font;
