@@ -1,13 +1,16 @@
 /*********
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
+*
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
-#include "frontend/settingsdialogs/btfontsettings.h"
+#include "btfontsettings.h"
 
 #include <QCheckBox>
 #include <QComboBox>
@@ -16,13 +19,13 @@
 #include <QLabel>
 #include <QVBoxLayout>
 #include <QWidget>
-#include "backend/config/btconfig.h"
-#include "bibletimeapp.h"
-#include "frontend/settingsdialogs/btfontchooserwidget.h"
-#include "frontend/settingsdialogs/cconfigurationdialog.h"
-#include "util/btconnect.h"
-#include "util/cresmgr.h"
-#include "util/tool.h"
+#include "../../backend/config/btconfig.h"
+#include "../../util/btconnect.h"
+#include "../../util/cresmgr.h"
+#include "../../util/tool.h"
+#include "../bibletimeapp.h"
+#include "btfontchooserwidget.h"
+#include "cconfigurationdialog.h"
 
 
 BtFontSettingsPage::BtFontSettingsPage(CConfigurationDialog *parent)
