@@ -1,24 +1,27 @@
 /*********
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
+*
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
-#include "frontend/settingsdialogs/btstandardworkstab.h"
+#include "btstandardworkstab.h"
 
 #include <QCheckBox>
 #include <QComboBox>
 #include <QFormLayout>
 #include <QLabel>
 #include <QVBoxLayout>
-#include "backend/config/btconfig.h"
-#include "backend/drivers/cswordlexiconmoduleinfo.h"
-#include "backend/managers/cswordbackend.h"
-#include "frontend/settingsdialogs/cswordsettings.h"
-#include "util/tool.h"
+#include "../../backend/config/btconfig.h"
+#include "../../backend/drivers/cswordlexiconmoduleinfo.h"
+#include "../../backend/managers/cswordbackend.h"
+#include "../../util/tool.h"
+#include "cswordsettings.h"
 
 
 BtStandardWorksTab::BtStandardWorksTab(CSwordSettingsPage *parent)
@@ -115,7 +118,7 @@ BtStandardWorksTab::BtStandardWorksTab(CSwordSettingsPage *parent)
 #define STANDARD_WORKS_COMBO_ADD(name) \
     comboList.append(m_ ## name ## Combo); \
     m = btConfig().getDefaultSwordModuleByType(#name); \
-    moduleList << (m != 0 ? m->config(CSwordModuleInfo::Description) : QString::null);
+    moduleList << (m != 0 ? m->config(CSwordModuleInfo::Description) : QString());
 
         STANDARD_WORKS_COMBO_ADD(standardBible);
         STANDARD_WORKS_COMBO_ADD(standardCommentary);
@@ -126,7 +129,7 @@ BtStandardWorksTab::BtStandardWorksTab(CSwordSettingsPage *parent)
         STANDARD_WORKS_COMBO_ADD(standardHebrewMorphLexicon);
         STANDARD_WORKS_COMBO_ADD(standardGreekMorphLexicon);
 
-    QString module = QString::null;
+    QString module = QString();
     int item = 0;
     int count = 0;
     QListIterator<QComboBox*> it(comboList);
