@@ -1,13 +1,16 @@
 /*********
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
+*
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
-#include "frontend/settingsdialogs/cacceleratorsettings.h"
+#include "cacceleratorsettings.h"
 
 #include <QComboBox>
 #include <QHBoxLayout>
@@ -16,18 +19,18 @@
 #include <QStackedWidget>
 #include <QVBoxLayout>
 #include <QWidget>
-#include "bibletime.h"
-#include "bibletimeapp.h"
-#include "frontend/displaywindow/btactioncollection.h"
-#include "frontend/displaywindow/cbiblereadwindow.h"
-#include "frontend/displaywindow/cbookreadwindow.h"
-#include "frontend/displaywindow/ccommentaryreadwindow.h"
-#include "frontend/displaywindow/clexiconreadwindow.h"
-#include "frontend/displaywindow/creadwindow.h"
-#include "frontend/messagedialog.h"
-#include "frontend/settingsdialogs/cconfigurationdialog.h"
-#include "util/btconnect.h"
-#include "util/cresmgr.h"
+#include "../../util/btconnect.h"
+#include "../../util/cresmgr.h"
+#include "../bibletime.h"
+#include "../bibletimeapp.h"
+#include "../displaywindow/btactioncollection.h"
+#include "../displaywindow/cbiblereadwindow.h"
+#include "../displaywindow/cbookreadwindow.h"
+#include "../displaywindow/ccommentaryreadwindow.h"
+#include "../displaywindow/clexiconreadwindow.h"
+#include "../displaywindow/creadwindow.h"
+#include "../messagedialog.h"
+#include "cconfigurationdialog.h"
 
 
 CAcceleratorSettingsPage::CAcceleratorSettingsPage(CConfigurationDialog *parent)
@@ -206,11 +209,11 @@ QString CAcceleratorSettingsPage::getTitleForEditor(BtShortcutsEditor* editor) {
         return m_bible.title;
     if (editor == m_commentary.keyChooser)
         return m_commentary.title;
-    if (editor == m_application.keyChooser)
+    if (editor == m_lexicon.keyChooser)
         return m_lexicon.title;
     if (editor == m_book.keyChooser)
         return m_book.title;
-    return QString::null;
+    return QString();
 }
 
 // Gets list of shortcuts editors that can conflict with a key change in the current shortcut editor
