@@ -1,29 +1,33 @@
 /*********
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
+*
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
-#include "frontend/settingsdialogs/cdisplaysettings.h"
+#include "cdisplaysettings.h"
 
 #include <QCheckBox>
 #include <QComboBox>
 #include <QLabel>
+#include <QLocale>
 #include <QVBoxLayout>
 #include <QFormLayout>
-#include "backend/config/btconfig.h"
-#include "backend/managers/cdisplaytemplatemgr.h"
-#include "backend/rendering/cdisplayrendering.h"
-#include "bibletimeapp.h"
-#include "frontend/btwebengineview.h"
-#include "frontend/settingsdialogs/cconfigurationdialog.h"
-#include "util/btassert.h"
-#include "util/btconnect.h"
-#include "util/cresmgr.h"
-#include "util/tool.h"
+#include "../../backend/config/btconfig.h"
+#include "../../backend/managers/colormanager.h"
+#include "../../backend/managers/cdisplaytemplatemgr.h"
+#include "../../backend/rendering/cdisplayrendering.h"
+#include "../../util/btassert.h"
+#include "../../util/btconnect.h"
+#include "../../util/cresmgr.h"
+#include "../../util/tool.h"
+#include "../bibletimeapp.h"
+#include "cconfigurationdialog.h"
 
 // Sword includes:
 #include <localemgr.h>
@@ -31,27 +35,6 @@
 
 using SBLCI = std::list<sword::SWBuf>::const_iterator;
 
-// ***********************
-// Container for BtWebEngineView to control its size
-class CWebViewerWidget : public QWidget {
-    public:
-        CWebViewerWidget(QWidget* parent = nullptr);
-        ~CWebViewerWidget();
-        QSize sizeHint() const override;
-};
-
-CWebViewerWidget::CWebViewerWidget(QWidget* parent)
-        : QWidget(parent) {
-}
-
-CWebViewerWidget::~CWebViewerWidget() {
-}
-
-QSize CWebViewerWidget::sizeHint () const {
-    return QSize(100, 100);
-}
-// ************************
-
 /** Initializes the startup section of the OD. */
 CDisplaySettingsPage::CDisplaySettingsPage(CConfigurationDialog *parent)
         : BtConfigDialog::Page(CResMgr::settings::startup::icon(), parent)
@@ -82,15 +65,19 @@ CDisplaySettingsPage::CDisplaySettingsPage(CConfigurationDialog *parent)
     formLayout->addRow(m_availableLabel, m_styleChooserCombo );
     mainLayout->addLayout(formLayout);
 
-    QWidget* webViewWidget = new CWebViewerWidget(this);
-    QLayout* webViewLayout = new QVBoxLayout(webViewWidget);
-    m_stylePreviewViewer = new BtWebEngineView(webViewWidget);
-    m_previewLabel = new QLabel(webViewWidget);
-    m_previewLabel->setBuddy(m_stylePreviewViewer);
-    webViewLayout->addWidget(m_previewLabel);
-    webViewLayout->addWidget(m_stylePreviewViewer);
-    webViewWidget->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Expanding);
-    mainLayout->addWidget(webViewWidget);
+    m_previewLabel = new QLabel(this);
+    m_previewLabel->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
+
+    m_stylePreviewViewer = new QLabel(this);
+    m_stylePreviewViewer->setWordWrap(true);
+    m_stylePreviewViewer->setTextFormat(Qt::RichText);
+    m_stylePreviewViewer->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Expanding);
+    m_stylePreviewViewer->setAlignment(Qt::AlignTop);
+    m_stylePreviewViewer->setMargin(15);
+    m_stylePreviewViewer->setAutoFillBackground(true);
+
+    mainLayout->addWidget(m_previewLabel);
+    mainLayout->addWidget(m_stylePreviewViewer);
 
     CDisplayTemplateMgr * tMgr = CDisplayTemplateMgr::instance();
     m_styleChooserCombo->addItems(tMgr->availableTemplates());
@@ -127,10 +114,10 @@ void CDisplaySettingsPage::retranslateUi() {
     m_transifexLabel->setWordWrap(true);
     m_transifexLabel->setOpenExternalLinks(true);
     m_transifexLabel->setText(tr(
-        "Did you know? You can help translating the GUI of BibleTime to your language at %1."
-    ).arg(QString("<a href=\"https://www.transifex.com/bibletime/bibletime/\">")
-          .append(tr("Transifex"))
-          .append("</a>")));
+        "Did you know? You can help translating the GUI of BibleTime to your "
+        "language at "
+        "<a href=\"https://www.transifex.com/bibletime/bibletime/\">Transifex"
+        "</a>."));
 }
 
 void CDisplaySettingsPage::resetLanguage() {
@@ -165,7 +152,7 @@ QVector<QString> CDisplaySettingsPage::bookNameAbbreviationsTryVector() {
             atv.append(settingsLanguage);
     }
     {
-        const QString localeLanguageAndCountry = QLocale::system().name();
+        const QString localeLanguageAndCountry = QLocale().name();
         if (!localeLanguageAndCountry.isEmpty()) {
             atv.append(localeLanguageAndCountry);
             int i = localeLanguageAndCountry.indexOf('_');
@@ -226,44 +213,44 @@ void CDisplaySettingsPage::updateStylePreview() {
     settings.highlight = false;
 
     tree.append( new CTextRendering::KeyTreeItem(
-                     QString("\n<span class=\"entryname\"><a name=\"John316\" href=\"sword://Bible/WEB/John 3:16\">16</a></span>%1")
-                     .arg(tr("For God so loved the world, that he gave his one and only Son, that whoever believes in him should not perish, but have eternal life.")),
+                     QString("\n<span class=\"entryname\"><a name=\"crossref\" href=\"sword://Bible/WEB/John 3:16\">16</a></span>%1")
+                     .arg(tr("<span class=\"jesuswords\"> For God so loved the world, that he gave his one and only Son, that whoever believes in him should not perish, but have eternal life.</span>")),
                      settings));
 
-    settings.highlight = true;
-
     tree.append( new CTextRendering::KeyTreeItem(
-                     QString("\n<span class=\"entryname\"><a name=\"John317\" href=\"sword://Bible/WEB/John 3:17\">17</a></span>%1")
-                     .arg(tr("For God didn't send his Son into the world to judge the world, but that the world should be saved through him.")),
+                     QString("\n<span class=\"entryname\"><a name=\"crossref\" href=\"sword://Bible/WEB/John 3:17\">17</a></span>%1")
+                     .arg(tr("<span class=\"jesuswords\">For God didn't send his Son into the world to judge the world, but that the world should be saved through him.</span>")),
                      settings));
 
-    settings.highlight = false;
-
     tree.append( new CTextRendering::KeyTreeItem(
-                     QString("\n<span class=\"entryname\"><a name=\"John318\" href=\"sword://Bible/WEB/John 3:18\">18</a></span>%1")
-                     .arg(tr("He who believes in him is not judged. He who doesn't believe has been judged already, because he has not believed in the name of the one and only Son of God.")),
+                     QString("\n<span class=\"entryname\"><a name=\"crossref\" href=\"sword://Bible/WEB/John 3:18\">18</a></span>%1")
+                     .arg(tr("<span class=\"jesuswords\">He who believes in him is not judged. He who doesn't believe has been judged already, because he has not believed in the name of the one and only Son of God.</span>")),
                      settings) );
 
     tree.append( new CTextRendering::KeyTreeItem(
-                     QString("\n<span class=\"entryname\"><a name=\"John319\" href=\"sword://Bible/WEB/John 3:19\">19</a></span>%1")
-                     .arg(tr("This is the judgement, that the light has come into the world, and men loved the darkness rather than the light; for their works were evil.")),
+                     QString("\n<span class=\"entryname\"><a name=\"crossref\" href=\"sword://Bible/WEB/John 3:19\">19</a></span>%1")
+                     .arg(tr("<span class=\"jesuswords\">This is the judgement, that the light has come into the world, and men loved the darkness rather than the light; for their works were evil.</span>")),
                      settings));
 
     tree.append( new CTextRendering::KeyTreeItem(
-                     QString("\n<span class=\"entryname\"><a name=\"John320\" href=\"sword://Bible/WEB/John 3:20\">20</a></span>%1<br/>")
-                     .arg(tr("For everyone who does evil hates the light, and doesn't come to the light, lest his works would be exposed.")),
+                     QString("\n<span class=\"entryname\"><a name=\"crossref\" href=\"sword://Bible/WEB/John 3:20\">20</a></span>%1<br/>")
+                     .arg(tr("<span class=\"jesuswords\">For everyone who does evil hates the light, and doesn't come to the light, lest his works would be exposed.</span>")),
                      settings));
 
     tree.append( new CTextRendering::KeyTreeItem(
-                     QString("\n<span class=\"entryname\"><a name=\"John321\" href=\"sword://Bible/WEB/John 3:21\">21</a></span>%1")
-                     .arg(tr("But he who does the truth comes to the light, that his works may be revealed, that they have been done in God.")),
+                     QString("\n<span class=\"entryname\"><a name=\"crossref\" href=\"sword://Bible/WEB/John 3:21\">21</a></span>%1")
+                     .arg(tr("<span class=\"jesuswords\">But he who does the truth comes to the light, that his works may be revealed, that they have been done in God.</span>")),
                      settings));
 
     /// \todo Remove the following hack:
     const QString oldStyleName = CDisplayTemplateMgr::activeTemplateName();
     btConfig().setValue("GUI/activeTemplateName", styleName);
     CDisplayRendering render;
-    m_stylePreviewViewer->setHtml( render.renderKeyTree(tree));
+    QString text = render.renderKeyTree(tree);
+    text.replace("#CHAPTERTITLE#", "");
+    updateColors();
+    text = ColorManager::instance().replaceColors(text);
+    m_stylePreviewViewer->setText(text);
 
     btConfig().setValue("GUI/activeTemplateName", oldStyleName);
 }
@@ -273,3 +260,10 @@ void CDisplaySettingsPage::save() {
     btConfig().setValue("GUI/activeTemplateName", m_styleChooserCombo->currentText());
     btConfig().setValue("GUI/booknameLanguage", m_swordLocaleCombo->itemData(m_swordLocaleCombo->currentIndex()));
 }
+
+void CDisplaySettingsPage::updateColors(const QString& style) {
+    QPalette p = m_stylePreviewViewer->palette();
+    p.setColor(QPalette::Window, ColorManager::instance().getBackgroundColor(style));
+    p.setColor(QPalette::WindowText, ColorManager::instance().getForegroundColor(style));
+    m_stylePreviewViewer->setPalette(p);
+}
