@@ -2,10 +2,11 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2014 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
@@ -18,9 +19,9 @@
 class CListWidget : public QListWidget {
         Q_OBJECT
     public:
-        CListWidget(QWidget* parent = 0);
+        CListWidget(QWidget* parent = nullptr);
 
-        virtual QSize sizeHint () const;
+        QSize sizeHint() const override;
         void setCharWidth(int width);
 };
 
